import React from 'react';
import { ReactCodeMirrorProps, ReactCodeMirrorRef, ViewUpdate } from '@uiw/react-codemirror';
import { CodeSandboxProps } from '@uiw/react-codesandbox';
import { CodepenProps } from '@uiw/react-codepen';
import { SplitProps } from '@uiw/react-split';
import './index.less';
export interface CodePreviewProps extends SplitProps {
    prefixCls?: string;
    style?: React.CSSProperties;
    /**
     * To specify a CSS class, use the className attribute.
     */
    className?: string;
    /**
     * Whether to display the border.
     */
    bordered?: boolean;
    /**
     * `JSX` source code
     */
    code?: string;
    /**
     * Whether to display the code interface.
     */
    noCode?: boolean;
    /**
     * Is the background white or plaid?
     */
    bgWhite?: boolean;
    /**
     * Only show Edit
     */
    onlyEdit?: boolean;
    /**
     * Whether to display the preview interface.
     */
    noPreview?: boolean;
    /**
     * Preview area does not display scroll bars
     */
    noScroll?: boolean;
    /**
     * Modify ReactCodemirror props.
     */
    editProps?: ReactCodeMirrorProps;
    /**
     * Dependent component
     */
    dependencies?: Record<string, any>;
    codePenOption?: CodepenProps & {
        /**
         * Packages that do not require comments.
         * @example ['uiw']
         */
        includeModule?: string[];
    };
    codeSandboxOption?: CodeSandboxProps;
    /** @default 'Code' */
    btnText?: string;
    /** @default 'Hide Editor' */
    btnHideText?: string;
}
export interface CodePreviewState {
    errorMessage: string;
    fullScreen: boolean;
    width: number | string;
    copied: boolean;
    showEdit: boolean;
}
export default class CodePreview extends React.PureComponent<CodePreviewProps, CodePreviewState> {
    demoDom: React.RefObject<HTMLDivElement>;
    editor: React.RefObject<ReactCodeMirrorRef>;
    initHeight: number;
    playerId: string;
    static defaultProps: CodePreviewProps;
    constructor(props: CodePreviewProps);
    componentDidMount(): void;
    componentDidUpdate(prevProps: CodePreviewProps): void;
    executeCode(codeStr: string): Promise<void>;
    /**
     * onCopyCode
     */
    onCopyCode(): void;
    /**
     * onFullScreen
     */
    onFullScreen(): void;
    initOldHeight(): void;
    handleChange(value: string, viewUpdate: ViewUpdate): void;
    /**
     * onSwitchSource
     */
    onSwitchSource(): void;
    render(): JSX.Element;
}
