import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
var _excluded = ["React", "ReactDOM"],
    _excluded2 = ["style", "prefixCls", "className", "editProps", "codePenOption", "codeSandboxOption", "code", "dependencies", "btnText", "btnHideText", "onlyEdit", "bordered", "noCode", "noPreview", "noScroll", "bgWhite"];
import React from 'react';
import ReactDOM from 'react-dom';
import CodeMirror from '@uiw/react-codemirror';
import copyTextToClipboard from '@uiw/copy-to-clipboard';
import { javascript } from '@codemirror/lang-javascript';
import Split from '@uiw/react-split';
import ThirdPartyButton from './ThirdPartyButton';
import * as icon from './icon';
import { babelTransform } from './transform';
import { ErrorMessage } from './ErrorMessage';
import "./index.css";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export default class CodePreview extends React.PureComponent {
  constructor(props) {
    super(props);
    this.demoDom = /*#__PURE__*/React.createRef();
    this.editor = /*#__PURE__*/React.createRef();
    this.initHeight = 3;
    this.playerId = "" + parseInt(String(Math.random() * 1e9), 10).toString(36);
    this.state = {
      errorMessage: '',
      fullScreen: false,
      copied: false,
      showEdit: false,
      width: 1
    };
  }

  componentDidMount() {
    if (!this.props.noPreview) {
      this.executeCode(this.props.code);
    }

    window.addEventListener('popstate', e => {
      document.body.style.overflow = 'inherit';
    }, false);
  }

  componentDidUpdate(prevProps) {
    if (prevProps.noPreview !== this.props.noPreview) {
      this.executeCode(prevProps.code);
    }
  }

  executeCode(codeStr) {
    var _this = this;

    return _asyncToGenerator(function* () {
      var {
        dependencies = {}
      } = _this.props;

      var {
        React: _React,
        ReactDOM: _ReactDOM
      } = dependencies,
          otherDeps = _objectWithoutPropertiesLoose(dependencies, _excluded);

      try {
        var deps = _extends({
          context: _this,
          React: _React || React,
          ReactDOM: _ReactDOM || ReactDOM
        }, otherDeps); // const args = ['context', 'React', 'ReactDOM', 'Component'];


        var args = []; // const argv = [this, React, ReactDOM, Component];

        var argv = [];

        for (var key in deps) {
          args.push(key);
          argv.push(deps[key]);
        }

        codeStr = codeStr.replace('_mount_', "document.getElementById('" + _this.playerId + "')");
        var input = "" + codeStr;
        var {
          code
        } = babelTransform(input);
        args.push(code || ''); // console.log('code:', argv)
        // eslint-disable-next-line no-new-func

        new Function(...args).apply(null, argv);

        _this.setState({
          errorMessage: ''
        });
      } catch (err) {
        var message = '';

        if (err && err.message) {
          message = err.message;
        } else {
          message = JSON.stringify(err);
        }

        _this.setState({
          errorMessage: message
        });
      }
    })();
  }
  /**
   * onCopyCode
   */


  onCopyCode() {
    var {
      code
    } = this.props;
    copyTextToClipboard(code || '', isCopy => {
      this.setState({
        copied: isCopy
      });
    });
    setTimeout(() => {
      this.setState({
        copied: false
      });
    }, 2000);
  }
  /**
   * onFullScreen
   */


  onFullScreen() {
    var {
      fullScreen
    } = this.state;
    this.setState({
      fullScreen: !fullScreen
    }, () => {
      document.body.style.overflow = !fullScreen ? 'hidden' : 'inherit';

      if (!fullScreen && this.demoDom.current) {
        this.demoDom.current.style.maxWidth = 'inherit';
      }
    });
  }

  initOldHeight() {
    var demo = this.demoDom.current;

    if (this.initHeight === 3 && demo) {
      this.initHeight = demo.clientHeight;
    }
  }

  handleChange(value, viewUpdate) {
    var {
      editProps
    } = this.props;
    this.executeCode(value);

    if (editProps && editProps.onChange) {
      editProps.onChange(value, viewUpdate);
    }
  }
  /**
   * onSwitchSource
   */


  onSwitchSource() {
    var {
      width
    } = this.state;
    this.initOldHeight();
    this.setState({
      width: width === 1 ? '50%' : 1,
      showEdit: true
    });
  }

  render() {
    var _this$props = this.props,
        {
      style,
      prefixCls,
      className,
      editProps,
      codePenOption,
      codeSandboxOption,
      btnText,
      btnHideText,
      onlyEdit,
      bordered,
      noCode,
      noPreview,
      noScroll,
      bgWhite
    } = _this$props,
        otherProps = _objectWithoutPropertiesLoose(_this$props, _excluded2);

    var isOneItem = !noCode && !noPreview ? false : !noCode || !noPreview;
    var visiable = this.state.width === 1 ? false : [isOneItem ? 1 : 2];
    return /*#__PURE__*/_jsxs(Split, _extends({
      visiable: visiable,
      className: [className, prefixCls, noScroll ? prefixCls + "-noScroll" : null, isOneItem ? prefixCls + "-OneItem" : null, bordered ? prefixCls + "-bordered" : null, this.state.fullScreen ? prefixCls + "-fullScreen" : null].filter(Boolean).join(' ').trim(),
      style: _extends({
        flex: 1
      }, style)
    }, otherProps, {
      children: [!noPreview && !onlyEdit && /*#__PURE__*/_jsxs("div", {
        ref: this.demoDom,
        className: [prefixCls + "-demo", !bgWhite ? prefixCls + "-demo-bgPlaid" : null, this.state.errorMessage ? prefixCls + "-demo-error" : null].filter(Boolean).join(' ').trim(),
        style: _extends({
          flex: 1
        }, this.state.width === 1 ? {
          width: '100%'
        } : {}),
        children: [/*#__PURE__*/_jsx(ErrorMessage, {
          message: this.state.errorMessage
        }), /*#__PURE__*/_jsx("div", {
          className: [prefixCls + "-demo-source", this.state.errorMessage ? 'error' : null].filter(Boolean).join(' ').trim(),
          id: this.playerId
        })]
      }), (!noCode || onlyEdit) && /*#__PURE__*/_jsx("div", {
        style: {
          overflow: 'hidden',
          width: onlyEdit ? '100%' : this.state.width
        },
        children: (this.state.showEdit || onlyEdit) && /*#__PURE__*/_jsx(CodeMirror, _extends({
          value: (this.props.code || '').replace(/\n$/, ''),
          ref: this.editor,
          extensions: [javascript({
            jsx: true
          })]
        }, editProps, {
          style: {
            height: '100%'
          },
          height: "100%",
          onChange: this.handleChange.bind(this)
        }))
      }), !isOneItem && !(noCode && noPreview) && !onlyEdit && /*#__PURE__*/_jsxs("div", {
        style: {
          flex: 1,
          width: 29
        },
        className: prefixCls + "-bar",
        children: [/*#__PURE__*/_jsx(ThirdPartyButton, {
          prefixCls: prefixCls,
          codePenOption: codePenOption,
          codeSandboxOption: codeSandboxOption
        }), /*#__PURE__*/_jsx("div", {
          className: prefixCls + "-bar-btn",
          onClick: this.onSwitchSource.bind(this),
          children: this.state.width === 1 ? btnText : btnHideText
        }), /*#__PURE__*/_jsx("div", {
          className: [prefixCls + "-bar-iconbtns", this.state.copied ? prefixCls + "-bar-copied" : null].filter(Boolean).join(' ').trim(),
          onClick: this.onCopyCode.bind(this),
          children: icon.copy
        }), /*#__PURE__*/_jsx("div", {
          className: [prefixCls + "-bar-iconbtns", this.state.fullScreen ? prefixCls + "-bar-copied" : null].filter(Boolean).join(' ').trim(),
          onClick: this.onFullScreen.bind(this),
          children: icon.full
        })]
      })]
    }));
  }

}
CodePreview.defaultProps = {
  prefixCls: 'w-code-preview',
  code: '',
  btnText: 'Code',
  btnHideText: 'Hide Editor',
  editProps: {},
  dependencies: {},
  noCode: false,
  bgWhite: false,
  onlyEdit: false,
  noPreview: false,
  bordered: true
};
//# sourceMappingURL=index.js.map